#!/bin/env python3
'''Pulls a WebDAV remote directory.
'''

import os
import argparse
from dotenv import load_dotenv
from webdav3.client import Client

load_dotenv()

def main():
    parser = argparse.ArgumentParser(description='Pulls a WebDAV remote directory.')
    parser.add_argument('remote_dir', type=str,
                   help='remote source path')
    parser.add_argument('local_dir', type=str,
                   help='local target path')
    args = parser.parse_args()

    options = {
     'webdav_hostname': os.getenv('WEBDAV_SYNC_REMOTE_URL'),
     'webdav_login':    os.getenv('WEBDAV_SYNC_REMOTE_USER'),
     'webdav_password': os.getenv('WEBDAV_SYNC_REMOTE_PASS'),
     'verify': True # Verify TLS connection
    }

    client = Client(options)
    client.pull(remote_directory=args.remote_dir, local_directory=args.local_dir)

if __name__ == '__main__':

    main()